<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>AboutDialog</name>
    <message>
        <source>Qt Linguist</source>
        <translation>Qt Linguist</translation>
    </message>
</context>
<context>
    <name>BatchTranslationDialog</name>
    <message>
        <source>Qt Linguist - Batch Translation</source>
        <translation>Qt Linguist - Пакетный перевод</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Параметры</translation>
    </message>
    <message>
        <source>Set translated entries to finished</source>
        <translation>Помечать переведенные записи как завершённые</translation>
    </message>
    <message>
        <source>Retranslate entries with existing translation</source>
        <translation>Переводить записи, уже имеющие перевод</translation>
    </message>
    <message>
        <source>Translate also finished entries</source>
        <translation>Также переводить записи с завершёнными переводами</translation>
    </message>
    <message>
        <source>Phrase book preference</source>
        <translation>Предпочитаемые глоссарии</translation>
    </message>
    <message>
        <source>Move up</source>
        <translation>Поднять</translation>
    </message>
    <message>
        <source>Move down</source>
        <translation>Опустить</translation>
    </message>
    <message>
        <source>&amp;Run</source>
        <translation>&amp;Выполнить</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Batch Translation of &apos;%1&apos; - Qt Linguist</source>
        <translation>Пакетный перевод «%1» - Qt Linguist</translation>
    </message>
    <message>
        <source>Searching, please wait...</source>
        <translation>Идёт поиск, ожидайте...</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>От&amp;мена</translation>
    </message>
    <message>
        <source>Linguist batch translator</source>
        <translation>Пакетный переводчик Qt Linguist</translation>
    </message>
    <message numerus="yes">
        <source>Batch translated %n entries</source>
        <translation>
            <numerusform>Автоматически переведена %n запись</numerusform>
            <numerusform>Автоматически переведены %n записи</numerusform>
            <numerusform>Автоматически переведено %n записей</numerusform>
        </translation>
    </message>
    <message>
        <source>Note that the modified entries will be reset to unfinished if &apos;Set translated entries to finished&apos; above is unchecked</source>
        <translation>Имейте в виду, что изменённые записи будут отмечены как незавершённые, если не включён параметр «Помечать переведённые записи как завершённые»</translation>
    </message>
    <message>
        <source>The batch translator will search through the selected phrase books in the order given above</source>
        <translation>Пакетный переводчик будет искать в выбранных глоссариях в указанном выше порядке</translation>
    </message>
</context>
<context>
    <name>DataModel</name>
    <message>
        <source>The translation file &apos;%1&apos; will not be loaded because it is empty.</source>
        <translation>Невозможно загрузить файл перевода «%1», так как он пуст.</translation>
    </message>
    <message>
        <source>&lt;qt&gt;Duplicate messages found in &apos;%1&apos;:</source>
        <translation>&lt;qt&gt;В «%1» обнаружены повторяющиеся сообщения:</translation>
    </message>
    <message>
        <source>&lt;p&gt;[more duplicates omitted]</source>
        <translation>&lt;p&gt;[остальные повторы не указаны]</translation>
    </message>
    <message>
        <source>&lt;p&gt;* ID: %1</source>
        <translation>&lt;p&gt;* ID: %1</translation>
    </message>
    <message>
        <source>&lt;p&gt;* Context: %1&lt;br&gt;* Source: %2</source>
        <translation>&lt;p&gt;* Контекст: %1&lt;br&gt;* Источник: %2</translation>
    </message>
    <message>
        <source>&lt;br&gt;* Comment: %3</source>
        <translation>&lt;br&gt;* Комментарий: %3</translation>
    </message>
    <message>
        <source>Linguist does not know the plural rules for &apos;%1&apos;.
Will assume a single universal form.</source>
        <translation>Qt Linguist не знает правила множественных форм для «%1».
Будет использована универсальная единичная форма.</translation>
    </message>
    <message>
        <source>Cannot create &apos;%2&apos;: %1</source>
        <translation>Не удалось создать «%2»: %1</translation>
    </message>
    <message>
        <source>Universal Form</source>
        <translation>Универсальная форма</translation>
    </message>
</context>
<context>
    <name>ErrorsView</name>
    <message>
        <source>Accelerator possibly superfluous in translation.</source>
        <translation>Возможно, лишний акселератор в переводе.</translation>
    </message>
    <message>
        <source>Accelerator possibly missing in translation.</source>
        <translation>Возможно, пропущен акселератор в переводе.</translation>
    </message>
    <message>
        <source>Translation does not end with the same punctuation as the source text.</source>
        <translation>Перевод не заканчивается тем же знаком препинания, что и исходный текст.</translation>
    </message>
    <message>
        <source>A phrase book suggestion for &apos;%1&apos; was ignored.</source>
        <translation>Предложение глоссария для «%1» пропущено.</translation>
    </message>
    <message>
        <source>Translation does not refer to the same place markers as in the source text.</source>
        <translation>Перевод не содержит тех же маркеров форматирования, что и исходный текст.</translation>
    </message>
    <message>
        <source>Translation does not contain the necessary %n place marker.</source>
        <translation>Перевод не содержит необходимого маркера форматирования %n.</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Неизвестная ошибка</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <source></source>
        <comment>Choose Edit|Find from the menu bar or press Ctrl+F to pop up the Find dialog</comment>
        <translation></translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Поиск</translation>
    </message>
    <message>
        <source>This window allows you to search for some text in the translation source file.</source>
        <translation>Данное окно позволяет искать текст в файле перевода.</translation>
    </message>
    <message>
        <source>&amp;Find what:</source>
        <translation>&amp;Искать:</translation>
    </message>
    <message>
        <source>Type in the text to search for.</source>
        <translation>Введите искомый текст.</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Параметры</translation>
    </message>
    <message>
        <source>Source texts are searched when checked.</source>
        <translation>Если отмечено, поиск будет вестись в исходных текстах.</translation>
    </message>
    <message>
        <source>&amp;Source texts</source>
        <translation>&amp;Исходные тексты</translation>
    </message>
    <message>
        <source>Translations are searched when checked.</source>
        <translation>Если отмечено, поиск будет вестись в переведённых текстах.</translation>
    </message>
    <message>
        <source>&amp;Translations</source>
        <translation>&amp;Переводы</translation>
    </message>
    <message>
        <source>Texts such as &apos;TeX&apos; and &apos;tex&apos; are considered as different when checked.</source>
        <translation>Если включено, строки «ПрИмЕр» и «пример» будут считаться разными.</translation>
    </message>
    <message>
        <source>&amp;Match case</source>
        <translation>С учётом &amp;регистра</translation>
    </message>
    <message>
        <source>Comments and contexts are searched when checked.</source>
        <translation>Если отмечено, поиск будет вестись по контекстам и комментариям.</translation>
    </message>
    <message>
        <source>&amp;Comments</source>
        <translation>&amp;Комментарии</translation>
    </message>
    <message>
        <source>Ignore &amp;accelerators</source>
        <translation>Пропускать &amp;акселераторы</translation>
    </message>
    <message>
        <source>Click here to find the next occurrence of the text you typed in.</source>
        <translation>Найти следующее совпадение для введённого текста.</translation>
    </message>
    <message>
        <source>Find Next</source>
        <translation>Найти далее</translation>
    </message>
    <message>
        <source>Click here to close this window.</source>
        <translation>Закрыть окно.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Obsoleted messages are skipped when checked.</source>
        <translation>Если включено, то пропускать устаревшие сообщения.</translation>
    </message>
    <message>
        <source>Skip &amp;obsolete</source>
        <translation>Пропускать &amp;устаревшие</translation>
    </message>
</context>
<context>
    <name>FormMultiWidget</name>
    <message>
        <source>Alt+Delete</source>
        <extracomment>translate, but don&apos;t change</extracomment>
        <translation>Alt+Delete</translation>
    </message>
    <message>
        <source>Shift+Alt+Insert</source>
        <extracomment>translate, but don&apos;t change</extracomment>
        <translation>Shift+Alt+Insert</translation>
    </message>
    <message>
        <source>Alt+Insert</source>
        <extracomment>translate, but don&apos;t change</extracomment>
        <translation>Alt+Insert</translation>
    </message>
    <message>
        <source>Confirmation - Qt Linguist</source>
        <translation>Подтверждение - Qt Linguist</translation>
    </message>
    <message>
        <source>Delete non-empty length variant?</source>
        <translation>Удалить вариант перевода?</translation>
    </message>
</context>
<context>
    <name>LRelease</name>
    <message numerus="yes">
        <source>Dropped %n message(s) which had no ID.</source>
        <translation>
            <numerusform>Удалено %n сообщение, у которого не было ID.</numerusform>
            <numerusform>Удалено %n сообщения, у которых не было ID.</numerusform>
            <numerusform>Удалено %n сообщений, у которых не было ID.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>Excess context/disambiguation dropped from %n message(s).</source>
        <translation>
            <numerusform>Удалён лишний контекст из %n сообщения.</numerusform>
            <numerusform>Удалён лишний контекст из %n сообщений.</numerusform>
            <numerusform>Удалён лишний контекст из %n сообщений.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>    Generated %n translation(s) (%1 finished and %2 unfinished)</source>
        <translation>
            <numerusform>    Создан %n перевод (%1 завершённых и %2 незавершённых)</numerusform>
            <numerusform>    Создано %n перевода (%1 завершённых и %2 незавершённых)</numerusform>
            <numerusform>    Создано %n переводов (%1 завершённых и %2 незавершённых)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>    Ignored %n untranslated source text(s)</source>
        <translation>
            <numerusform>    Пропущен %n непереведённый исходный текст</numerusform>
            <numerusform>    Пропущено %n непереведённых исходных текста</numerusform>
            <numerusform>    Пропущено %n непереведённых исходных текстов</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>Linguist</name>
    <message>
        <source>GNU Gettext localization files</source>
        <translation>Файлы локализации GNU Gettext</translation>
    </message>
    <message>
        <source>GNU Gettext localization template files</source>
        <translation>Файлы шаблонов локализации GNU Gettext</translation>
    </message>
    <message>
        <source>Compiled Qt translations</source>
        <translation>Скомпилированные переводы Qt</translation>
    </message>
    <message>
        <source>Qt Linguist &apos;Phrase Book&apos;</source>
        <translation>«Глоссарий» Qt Linguist</translation>
    </message>
    <message>
        <source>Qt translation sources</source>
        <translation>Исходники переводов Qt</translation>
    </message>
    <message>
        <source>XLIFF localization files</source>
        <translation>Файлы локализации XLIFF</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source></source>
        <comment>This is the application&apos;s main window.</comment>
        <translatorcomment>Основное окно программы.</translatorcomment>
        <translation></translation>
    </message>
    <message>
        <source>Source text</source>
        <translation>Исходный текст</translation>
    </message>
    <message>
        <source>Index</source>
        <translation>Индекс</translation>
    </message>
    <message>
        <source>Context</source>
        <translation>Контекст</translation>
    </message>
    <message>
        <source>Items</source>
        <translation>Записи</translation>
    </message>
    <message>
        <source>This panel lists the source contexts.</source>
        <translation>В данной панели перечислены исходные контексты.</translation>
    </message>
    <message>
        <source>Strings</source>
        <translation>Строки</translation>
    </message>
    <message>
        <source>Phrases and guesses</source>
        <translation>Похожие переводы</translation>
    </message>
    <message>
        <source>Sources and Forms</source>
        <translation>Исходники и формы</translation>
    </message>
    <message>
        <source>Warnings</source>
        <translation>Предупреждения</translation>
    </message>
    <message>
        <source> MOD </source>
        <comment>status bar: file(s) modified</comment>
        <translation> ИЗМ </translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation>Загрузка...</translation>
    </message>
    <message>
        <source>Loading File - Qt Linguist</source>
        <translation>Загрузка файла - Qt Linguist</translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; does not seem to be related to the currently open file(s) &apos;%2&apos;.

Close the open file(s) first?</source>
        <translation>Файл «%1», похоже, не связан с открытым файлом(ами) «%2».

Закрыть открытые файлы?</translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; does not seem to be related to the file &apos;%2&apos; which is being loaded as well.

Skip loading the first named file?</source>
        <translation>Файл «%1», похоже, не связан с загруженным файлом «%2».

Пропустить загрузку файла?</translation>
    </message>
    <message numerus="yes">
        <source>%n translation unit(s) loaded.</source>
        <translation>
            <numerusform>Загружена %n запись.</numerusform>
            <numerusform>Загружено %n записи.</numerusform>
            <numerusform>Загружено %n записей.</numerusform>
        </translation>
    </message>
    <message>
        <source>Related files (%1);;</source>
        <translation>Связанные файлы (%1);;</translation>
    </message>
    <message>
        <source>Open Translation Files</source>
        <translation>Открыть файлы перевода</translation>
    </message>
    <message>
        <source>File saved.</source>
        <translation>Файл сохранён.</translation>
    </message>
    <message>
        <source>Release</source>
        <translation>Скомпилировать</translation>
    </message>
    <message>
        <source>Qt message files for released applications (*.qm)
All files (*)</source>
        <translation>Скомпилированные файлы перевода для приложений Qt (*.qm)
Все файлы (*)</translation>
    </message>
    <message>
        <source>File created.</source>
        <translation>Файл создан.</translation>
    </message>
    <message>
        <source>Printing...</source>
        <translation>Печать...</translation>
    </message>
    <message>
        <source>Context: %1</source>
        <translation>Контекст: %1</translation>
    </message>
    <message>
        <source>finished</source>
        <translation>завершён</translation>
    </message>
    <message>
        <source>unresolved</source>
        <translation>неразрешённый</translation>
    </message>
    <message>
        <source>obsolete</source>
        <translation>устаревший</translation>
    </message>
    <message>
        <source>Printing... (page %1)</source>
        <translation>Печать... (страница %1)</translation>
    </message>
    <message>
        <source>Printing completed</source>
        <translation>Печать завершена</translation>
    </message>
    <message>
        <source>Printing aborted</source>
        <translation>Печать прервана</translation>
    </message>
    <message>
        <source>Search wrapped.</source>
        <translation>Поиск с начала.</translation>
    </message>
    <message>
        <source>Qt Linguist</source>
        <translation>Qt Linguist</translation>
    </message>
    <message>
        <source>Cannot find the string &apos;%1&apos;.</source>
        <translation>Не удалось найти строку «%1».</translation>
    </message>
    <message>
        <source>Search And Translate in &apos;%1&apos; - Qt Linguist</source>
        <translation>Поиск и перевод «%1» - Qt Linguist</translation>
    </message>
    <message>
        <source>Translate - Qt Linguist</source>
        <translation>Перевод - Qt Linguist</translation>
    </message>
    <message numerus="yes">
        <source>Translated %n entry(s)</source>
        <translation>
            <numerusform>Переведена %n запись</numerusform>
            <numerusform>Переведено %n записи</numerusform>
            <numerusform>Переведено %n записей</numerusform>
        </translation>
    </message>
    <message>
        <source>No more occurrences of &apos;%1&apos;. Start over?</source>
        <translation>Нет больше совпадений с «%1». Начать заново?</translation>
    </message>
    <message>
        <source>Create New Phrase Book</source>
        <translation>Создать глоссарий</translation>
    </message>
    <message>
        <source>Qt phrase books (*.qph)
All files (*)</source>
        <translation>Глоссарии Qt (*.qph)
Все файлы (*)</translation>
    </message>
    <message>
        <source>Phrase book created.</source>
        <translation>Глоссарий создан.</translation>
    </message>
    <message>
        <source>Open Phrase Book</source>
        <translation>Открыть глоссарий</translation>
    </message>
    <message>
        <source>Qt phrase books (*.qph);;All files (*)</source>
        <translation>Глоссарии Qt (*.qph);;Все файлы (*)</translation>
    </message>
    <message numerus="yes">
        <source>%n phrase(s) loaded.</source>
        <translation>
            <numerusform>Загружена %n фраза.</numerusform>
            <numerusform>Загружено %n фразы.</numerusform>
            <numerusform>Загружено %n фраз.</numerusform>
        </translation>
    </message>
    <message>
        <source>Add to phrase book</source>
        <translation>Добавить в глоссарий</translation>
    </message>
    <message>
        <source>No appropriate phrasebook found.</source>
        <translation>Подходящий глоссарий не найден.</translation>
    </message>
    <message>
        <source>Adding entry to phrasebook %1</source>
        <translation>Добавление записи в глоссарий %1</translation>
    </message>
    <message>
        <source>Select phrase book to add to</source>
        <translation>Выберите глоссарий, в который желаете добавить фразу</translation>
    </message>
    <message>
        <source>Unable to launch Qt Assistant (%1)</source>
        <translation>Не удалось запустить Qt Assistant (%1)</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Версия %1</translation>
    </message>
    <message>
        <source>&lt;center&gt;&lt;img src=&quot;:/images/splash.png&quot;/&gt;&lt;/img&gt;&lt;p&gt;%1&lt;/p&gt;&lt;/center&gt;&lt;p&gt;Qt Linguist is a tool for adding translations to Qt applications.&lt;/p&gt;&lt;p&gt;Copyright (C) %2 The Qt Company Ltd.</source>
        <translation>&lt;center&gt;&lt;img src=&quot;:/images/splash.png&quot;/&gt;&lt;/img&gt;&lt;p&gt;%1&lt;/p&gt;&lt;/center&gt;&lt;p&gt;Qt Linguist – утилита для добавления переводов приложений Qt.&lt;/p&gt;&lt;p&gt;Copyright (C) %2 The Qt Company Ltd.</translation>
    </message>
    <message>
        <source>Do you want to save the modified files?</source>
        <translation>Желаете сохранить изменённые файлы?</translation>
    </message>
    <message>
        <source>Do you want to save &apos;%1&apos;?</source>
        <translation>Желаете сохранить «%1»?</translation>
    </message>
    <message>
        <source>Qt Linguist[*]</source>
        <translation>Qt Linguist[*]</translation>
    </message>
    <message>
        <source>%1[*] - Qt Linguist</source>
        <translation>%1[*] - Qt Linguist</translation>
    </message>
    <message>
        <source>No untranslated translation units left.</source>
        <translation>Непереведённых записей не осталось.</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Окно</translation>
    </message>
    <message>
        <source>Minimize</source>
        <translation>Свернуть</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation></translation>
    </message>
    <message>
        <source>Display the manual for %1.</source>
        <translation>Показать руководство для %1.</translation>
    </message>
    <message>
        <source>Display information about %1.</source>
        <translation>Показать информацию о %1.</translation>
    </message>
    <message>
        <source>&amp;Save &apos;%1&apos;</source>
        <translation>&amp;Сохранить «%1»</translation>
    </message>
    <message>
        <source>Save &apos;%1&apos; &amp;As...</source>
        <translation>Сохранить «%1» &amp;как...</translation>
    </message>
    <message>
        <source>Release &apos;%1&apos;</source>
        <translation>Скомпилировать «%1»</translation>
    </message>
    <message>
        <source>Release &apos;%1&apos; As...</source>
        <translation>Скомпилировать «%1» как...</translation>
    </message>
    <message>
        <source>&amp;Close &apos;%1&apos;</source>
        <translation>&amp;Закрыть «%1»</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Сохранить</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>Сохранить &amp;как...</translation>
    </message>
    <message>
        <source>Release As...</source>
        <translation>Скомпилировать как...</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Закрыть</translation>
    </message>
    <message>
        <source>Save All</source>
        <translation>Сохранить все</translation>
    </message>
    <message>
        <source>&amp;Release All</source>
        <translation>С&amp;компилировать все</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Закрыть все</translation>
    </message>
    <message>
        <source>&amp;Release</source>
        <translation>С&amp;компилировать</translation>
    </message>
    <message>
        <source>Translation File &amp;Settings for &apos;%1&apos;...</source>
        <translation>&amp;Параметры файла перевода для «%1»...</translation>
    </message>
    <message>
        <source>&amp;Batch Translation of &apos;%1&apos;...</source>
        <translation>Пак&amp;етный перевод «%1»...</translation>
    </message>
    <message>
        <source>Search And &amp;Translate in &apos;%1&apos;...</source>
        <translation>&amp;Найти и перевести в «%1»...</translation>
    </message>
    <message>
        <source>Translation File &amp;Settings...</source>
        <translation>&amp;Параметры файла перевода...</translation>
    </message>
    <message>
        <source>&amp;Batch Translation...</source>
        <translation>Пак&amp;етный перевод...</translation>
    </message>
    <message>
        <source>Search And &amp;Translate...</source>
        <translation>&amp;Найти и перевести...</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Файл</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Правка</translation>
    </message>
    <message>
        <source>Translation</source>
        <translation>Перевод</translation>
    </message>
    <message>
        <source>Validation</source>
        <translation>Проверка</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Справка</translation>
    </message>
    <message>
        <source>Cannot read from phrase book &apos;%1&apos;.</source>
        <translation>Не удалось прочитать из глоссария «%1».</translation>
    </message>
    <message>
        <source>Close this phrase book.</source>
        <translation>Закрыть глоссарий.</translation>
    </message>
    <message>
        <source>Enables you to add, modify, or delete entries in this phrase book.</source>
        <translation>Позволяет добавлять, изменять и удалять записи в глоссарии.</translation>
    </message>
    <message>
        <source>Print the entries in this phrase book.</source>
        <translation>Печать записей фраз глоссария.</translation>
    </message>
    <message>
        <source>Cannot create phrase book &apos;%1&apos;.</source>
        <translation>Не удалось создать глоссарий «%1».</translation>
    </message>
    <message>
        <source>Do you want to save phrase book &apos;%1&apos;?</source>
        <translation>Желаете сохранить глоссарий «%1»?</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Все</translation>
    </message>
    <message>
        <source>MainWindow</source>
        <translation>Главное окно</translation>
    </message>
    <message>
        <source>&amp;Phrases</source>
        <translation>&amp;Глоссарии</translation>
    </message>
    <message>
        <source>&amp;Close Phrase Book</source>
        <translation>&amp;Закрыть глоссарий</translation>
    </message>
    <message>
        <source>&amp;Edit Phrase Book</source>
        <translation>&amp;Редактироваь глоссарий</translation>
    </message>
    <message>
        <source>&amp;Print Phrase Book</source>
        <translation>&amp;Печатать глоссарий</translation>
    </message>
    <message>
        <source>V&amp;alidation</source>
        <translation>П&amp;роверка</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Вид</translation>
    </message>
    <message>
        <source>Vie&amp;ws</source>
        <translation>&amp;Панели</translation>
    </message>
    <message>
        <source>&amp;Toolbars</source>
        <translation>Пан&amp;ели инструментов</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Справка</translation>
    </message>
    <message>
        <source>&amp;Translation</source>
        <translation>П&amp;еревод</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <source>Recently Opened &amp;Files</source>
        <translation>Недавно открытые &amp;файлы</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Правка</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>&amp;Открыть...</translation>
    </message>
    <message>
        <source>Open a Qt translation source file (TS file) for editing</source>
        <translation>Открыть исходный файл переводов Qt (файл TS) для изменения</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>В&amp;ыход</translation>
    </message>
    <message>
        <source>Close this window and exit.</source>
        <translation>Закрыть окно и выйти.</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <source>Save changes made to this Qt translation source file</source>
        <translation>Сохранить изменения в данном исходном файле перевода Qt</translation>
    </message>
    <message>
        <source>Save As...</source>
        <translation>Сохранить как...</translation>
    </message>
    <message>
        <source>Save changes made to this Qt translation source file into a new file.</source>
        <translation>Сохранить изменения в данном исходном файле перевода Qt в новый файл.</translation>
    </message>
    <message>
        <source>Create a Qt message file suitable for released applications from the current message file.</source>
        <translation>Скомпилировать файл перевода Qt из текущего файла.</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>&amp;Печать...</translation>
    </message>
    <message>
        <source>Print a list of all the translation units in the current translation source file.</source>
        <translation>Печать списка всех записей перевода из текущего файла.</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Отменить</translation>
    </message>
    <message>
        <source>Undo the last editing operation performed on the current translation.</source>
        <translation>Отменить последнее изменение текущего перевода.</translation>
    </message>
    <message>
        <source>Ctrl+Z</source>
        <translation>Ctrl+Z</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>&amp;Повторить</translation>
    </message>
    <message>
        <source>Redo an undone editing operation performed on the translation.</source>
        <translation>Повторить отменённую правку перевода.</translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <translation>Ctrl+Y</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>Выр&amp;езать</translation>
    </message>
    <message>
        <source>Copy the selected translation text to the clipboard and deletes it.</source>
        <translation>Скопировать отмеченный текст в буфер обмена и удалить его из оригинала.</translation>
    </message>
    <message>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Копировать</translation>
    </message>
    <message>
        <source>Copy the selected translation text to the clipboard.</source>
        <translation>Скопировать отмеченный текст в буфер обмена.</translation>
    </message>
    <message>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>&amp;Вставить</translation>
    </message>
    <message>
        <source>Paste the clipboard text into the translation.</source>
        <translation>Вставить текст из буфера обмена в перевод.</translation>
    </message>
    <message>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation>В&amp;ыделить всё</translation>
    </message>
    <message>
        <source>Select the whole translation text.</source>
        <translation>Выделить весь текст перевода.</translation>
    </message>
    <message>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <source>&amp;Find...</source>
        <translation>&amp;Найти...</translation>
    </message>
    <message>
        <source>Search for some text in the translation source file.</source>
        <translation>Найти текст в исходном файле перевода.</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation>Найти д&amp;алее</translation>
    </message>
    <message>
        <source>Continue the search where it was left.</source>
        <translation>Продолжить поиск с места, где он был остановлен.</translation>
    </message>
    <message>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <source>&amp;Prev Unfinished</source>
        <translation>&amp;Предыдущий незавершённый</translation>
    </message>
    <message>
        <source>Create a Qt message file suitable for released applications from the current message file. The filename will automatically be determined from the name of the TS file.</source>
        <translation>Создание готового файла перевода Qt из текущего файла. Имя файла будет автоматически определено из имени .ts файла.</translation>
    </message>
    <message>
        <source>Length Variants</source>
        <translation>Варианты перевода</translation>
    </message>
    <message>
        <source>Move to the previous unfinished item.</source>
        <translation>Перейти к предыдущему незавершённому переводу.</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>&amp;Next Unfinished</source>
        <translation>&amp;Следующий незавершённый</translation>
    </message>
    <message>
        <source>Move to the next unfinished item.</source>
        <translation>Перейти к следующему незавершённому переводу.</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>P&amp;rev</source>
        <translation>Пр&amp;едыдущий</translation>
    </message>
    <message>
        <source>Move to the previous item.</source>
        <translation>Перейти к предыдущему переводу.</translation>
    </message>
    <message>
        <source>Ctrl+Shift+K</source>
        <translation>Ctrl+Shift+K</translation>
    </message>
    <message>
        <source>Ne&amp;xt</source>
        <translation>С&amp;ледующий</translation>
    </message>
    <message>
        <source>Move to the next item.</source>
        <translation>Перейти к следующему переводу.</translation>
    </message>
    <message>
        <source>Ctrl+Shift+J</source>
        <translation>Ctrl+Shift+J</translation>
    </message>
    <message>
        <source>&amp;Done and Next</source>
        <translation>&amp;Готово и далее</translation>
    </message>
    <message>
        <source>Mark this item as done and move to the next unfinished item.</source>
        <translation>Пометить перевод как завершённый и перейти к следующему незавершённому.</translation>
    </message>
    <message>
        <source>Copy from source text</source>
        <translation>Скопировать из исходного текста</translation>
    </message>
    <message>
        <source>Copies the source text into the translation field.</source>
        <translation>Скопировать исходный текст в поле перевода.</translation>
    </message>
    <message>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <source>&amp;Accelerators</source>
        <translation>&amp;Акселераторы</translation>
    </message>
    <message>
        <source>Toggle the validity check of accelerators, i.e. whether the number of ampersands in the source and translation text is the same. If the check fails, a message is shown in the warnings window.</source>
        <translation>Переключение проверки акселераторов, т.е. совпадает ли количество амперсандов в исходном и переведённом текстах. Если выявлено несовпадение, будет показано сообщение в окне предупреждений.</translation>
    </message>
    <message>
        <source>&amp;Ending Punctuation</source>
        <translation>&amp;Знаки препинания</translation>
    </message>
    <message>
        <source>Toggle the validity check of ending punctuation. If the check fails, a message is shown in the warnings window.</source>
        <translation>Переключение проверки знаков препинания в конце текста. Если выявлено несовпадение, будет показано сообщение в окне предупреждений.</translation>
    </message>
    <message>
        <source>&amp;Phrase matches</source>
        <translation>Совпадение &amp;фраз</translation>
    </message>
    <message>
        <source>Toggle checking that phrase suggestions are used. If the check fails, a message is shown in the warnings window.</source>
        <translation>Переключение проверки использования предложений для фраз. Если выявлено несовпадение, будет показано сообщение в окне предупреждений.</translation>
    </message>
    <message>
        <source>Place &amp;Marker Matches</source>
        <translation>Совпадение &amp;маркеров</translation>
    </message>
    <message>
        <source>Toggle the validity check of place markers, i.e. whether %1, %2, ... are used consistently in the source text and translation text. If the check fails, a message is shown in the warnings window.</source>
        <translation>Переключение проверки маркеров форматирования, т.е. все ли маркеры (%1, %2, ...) исходного текста присутствуют в переведённом. Если выявлено несовпадение, будет показано сообщение в окне предупреждений.</translation>
    </message>
    <message>
        <source>&amp;New Phrase Book...</source>
        <translation>&amp;Новый глоссарий...</translation>
    </message>
    <message>
        <source>Create a new phrase book.</source>
        <translation>Создать глоссарий.</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <source>&amp;Open Phrase Book...</source>
        <translation>&amp;Открыть глоссарий...</translation>
    </message>
    <message>
        <source>Open a phrase book to assist translation.</source>
        <translation>Открыть глоссарий для помощи в переводе.</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <source>&amp;Reset Sorting</source>
        <translation>С&amp;брос сортировки</translation>
    </message>
    <message>
        <source>Sort the items back in the same order as in the message file.</source>
        <translation>Упорядочить элементы в той последовательности, в которой они находятся в файле.</translation>
    </message>
    <message>
        <source>&amp;Display guesses</source>
        <translation>П&amp;охожие переводы</translation>
    </message>
    <message>
        <source>Set whether or not to display translation guesses.</source>
        <translation>Определяет необходимо или нет отображать похожие переводы.</translation>
    </message>
    <message>
        <source>&amp;Statistics</source>
        <translation>&amp;Статистика</translation>
    </message>
    <message>
        <source>Display translation statistics.</source>
        <translation>Показать статистику перевода.</translation>
    </message>
    <message>
        <source>&amp;Manual</source>
        <translation>&amp;Руководство</translation>
    </message>
    <message>
        <source>F1</source>
        <translation>F1</translation>
    </message>
    <message>
        <source>About Qt Linguist</source>
        <translation>О Qt Linguist</translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation>О Qt</translation>
    </message>
    <message>
        <source>&amp;What&apos;s This?</source>
        <translation>&amp;Что это?</translation>
    </message>
    <message>
        <source>What&apos;s This?</source>
        <translation>Что это?</translation>
    </message>
    <message>
        <source>Enter What&apos;s This? mode.</source>
        <translation>Переход в режим &quot;Что это?&quot;.</translation>
    </message>
    <message>
        <source>Shift+F1</source>
        <translation>Shift+F1</translation>
    </message>
    <message>
        <source>&amp;Search And Translate...</source>
        <translation>&amp;Найти и перевести...</translation>
    </message>
    <message>
        <source>Replace the translation on all entries that matches the search source text.</source>
        <translation>Заменить перевод всех записей, которые совпадают с искомым исходным текстом.</translation>
    </message>
    <message>
        <source>Batch translate all entries using the information in the phrase books.</source>
        <translation>Перевести все записи в пакетном режиме, используя информацию из глоссария.</translation>
    </message>
    <message>
        <source>Open/Refresh Form &amp;Preview</source>
        <translation>Открыть/обновить предпрос&amp;мотр формы</translation>
    </message>
    <message>
        <source>Form Preview Tool</source>
        <translation>Инструмент предпросмотра форм</translation>
    </message>
    <message>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <source>&amp;Add to Phrase Book</source>
        <translation>&amp;Добавить в глоссарий</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>Open Read-O&amp;nly...</source>
        <translation>Открыть только для &amp;чтения...</translation>
    </message>
    <message>
        <source>&amp;Save All</source>
        <translation>&amp;Сохранить все</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <source>&amp;Close All</source>
        <translation>&amp;Закрыть все</translation>
    </message>
    <message>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <source>Previous unfinished item</source>
        <translation>Предыдущий незавершённый перевод</translation>
    </message>
    <message>
        <source>Next unfinished item</source>
        <translation>Следующий незавершённый перевод</translation>
    </message>
    <message>
        <source>Move to previous item</source>
        <translation>Перейти к предыдущему переводу</translation>
    </message>
    <message>
        <source>Next item</source>
        <translation>Следующий перевод</translation>
    </message>
    <message>
        <source>Mark item as done and move to the next unfinished item</source>
        <translation>Пометить перевод как завершённый и перейти к следующему незавершённому</translation>
    </message>
    <message>
        <source>Copies the source text into the translation field</source>
        <translation>Скопировать исходный текст в поле перевода</translation>
    </message>
    <message>
        <source>Toggle the validity check of accelerators</source>
        <translation>Переключение проверки акселераторов</translation>
    </message>
    <message>
        <source>Toggle the validity check of ending punctuation</source>
        <translation>Переключение проверки знаков препинания в конце текста</translation>
    </message>
    <message>
        <source>Toggle checking that phrase suggestions are used</source>
        <translation>Переключение проверки использования предложений для фраз</translation>
    </message>
    <message>
        <source>Toggle the validity check of place markers</source>
        <translation>Переключение проверки маркеров форматирования</translation>
    </message>
    <message>
        <source>Display information about the Qt toolkit by Digia.</source>
        <translation>Показать информацию об инструментарии Qt от Digia.</translation>
    </message>
    <message>
        <source>&amp;Zoom</source>
        <translation>&amp;Масштаб</translation>
    </message>
    <message>
        <source>Visualize whitespace</source>
        <translation>Отображать пробелы</translation>
    </message>
    <message>
        <source>Toggle visualize whitespace in editors</source>
        <translation>Переключение режима отображения в редакторах непечатаемых символов</translation>
    </message>
    <message>
        <source>Increase</source>
        <translation>Увеличить</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Decrease</source>
        <translation>Уменьшить</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Reset to default</source>
        <translation>По умолчанию</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
</context>
<context>
    <name>MessageEditor</name>
    <message>
        <source></source>
        <comment>This is the right panel of the main window.</comment>
        <translatorcomment>Правая панель основного окна</translatorcomment>
        <translation></translation>
    </message>
    <message>
        <source>Russian</source>
        <translation>Русский</translation>
    </message>
    <message>
        <source>German</source>
        <translation>Немецкий</translation>
    </message>
    <message>
        <source>Japanese</source>
        <translation>Японский</translation>
    </message>
    <message>
        <source>French</source>
        <translation>Французский</translation>
    </message>
    <message>
        <source>Polish</source>
        <translation>Польский</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>Китайский</translation>
    </message>
    <message>
        <source>This whole panel allows you to view and edit the translation of some source text.</source>
        <translation>Данная панель позволяет просматривать и редактировать перевод исходного текста.</translation>
    </message>
    <message>
        <source>Source text</source>
        <translation>Исходный текст</translation>
    </message>
    <message>
        <source>This area shows the source text.</source>
        <translation>В данной области отображается исходный текст.</translation>
    </message>
    <message>
        <source>Source text (Plural)</source>
        <translation>Исходный текст (множественная форма)</translation>
    </message>
    <message>
        <source>This area shows the plural form of the source text.</source>
        <translation>В данной области отображается исходный текст во множественной форме.</translation>
    </message>
    <message>
        <source>Developer comments</source>
        <translation>Комментарий разработчика</translation>
    </message>
    <message>
        <source>This area shows a comment that may guide you, and the context in which the text occurs.</source>
        <translation>В данной области отображается комментарий, который поможет определить в каком контексте встречается переводимый текст.</translation>
    </message>
    <message>
        <source>Here you can enter comments for your own use. They have no effect on the translated applications.</source>
        <translation>Здесь вы можете оставить комментарий для собственного использования. Комментарии не влияют на перевод приложений.</translation>
    </message>
    <message>
        <source>%1 translation (%2)</source>
        <translation>%1 перевод (%2)</translation>
    </message>
    <message>
        <source>This is where you can enter or modify the translation of the above source text.</source>
        <translation>Здесь вы можете ввести или изменить перевод текста, представленного выше.</translation>
    </message>
    <message>
        <source>%1 translation</source>
        <translation>%1 перевод</translation>
    </message>
    <message>
        <source>%1 translator comments</source>
        <translation>%1 перевод: комментарий переводчика</translation>
    </message>
    <message>
        <source>&apos;%1&apos;
Line: %2</source>
        <translation>«%1»
Строка: %2</translation>
    </message>
</context>
<context>
    <name>MessageModel</name>
    <message>
        <source>Completion status for %1</source>
        <translation>Состояние завершённости для %1</translation>
    </message>
    <message>
        <source>&lt;file header&gt;</source>
        <translation>&lt;заголовок файла&gt;</translation>
    </message>
    <message>
        <source>&lt;context comment&gt;</source>
        <translation>&lt;контекстный комментарий&gt;</translation>
    </message>
    <message>
        <source>&lt;unnamed context&gt;</source>
        <translation>&lt;безымянный контекст&gt;</translation>
    </message>
</context>
<context>
    <name>PhraseBook</name>
    <message>
        <source>Parse error at line %1, column %2 (%3).</source>
        <translation>Ошибка разбора в строке %1, столбце %2 (%3).</translation>
    </message>
</context>
<context>
    <name>PhraseBookBox</name>
    <message>
        <source></source>
        <comment>Go to Phrase &gt; Edit Phrase Book... The dialog that pops up is a PhraseBookBox.</comment>
        <translation></translation>
    </message>
    <message>
        <source>(New Entry)</source>
        <translation>(Новая запись)</translation>
    </message>
    <message>
        <source>%1[*] - Qt Linguist</source>
        <translation>%1[*] - Qt Linguist</translation>
    </message>
    <message>
        <source>Qt Linguist</source>
        <translation>Qt Linguist</translation>
    </message>
    <message>
        <source>Cannot save phrase book &apos;%1&apos;.</source>
        <translation>Не удалось сохранить глоссарий «%1».</translation>
    </message>
    <message>
        <source>Edit Phrase Book</source>
        <translation>Правка глоссария</translation>
    </message>
    <message>
        <source>This window allows you to add, modify, or delete entries in a phrase book.</source>
        <translation>Данное окно позволяет добавлять, изменять и удалять записи в глоссарии.</translation>
    </message>
    <message>
        <source>&amp;Translation:</source>
        <translation>&amp;Перевод:</translation>
    </message>
    <message>
        <source>This is the phrase in the target language corresponding to the source phrase.</source>
        <translation>Перевод, соответствующий исходной фразе.</translation>
    </message>
    <message>
        <source>S&amp;ource phrase:</source>
        <translation>&amp;Исходная фраза:</translation>
    </message>
    <message>
        <source>This is a definition for the source phrase.</source>
        <translation>Определение исходной фразы.</translation>
    </message>
    <message>
        <source>This is the phrase in the source language.</source>
        <translation>Фраза на исходном языке.</translation>
    </message>
    <message>
        <source>&amp;Definition:</source>
        <translation>&amp;Определение:</translation>
    </message>
    <message>
        <source>Click here to add the phrase to the phrase book.</source>
        <translation>Добавить фразу в глоссарий.</translation>
    </message>
    <message>
        <source>&amp;New Entry</source>
        <translation>Новая &amp;запись</translation>
    </message>
    <message>
        <source>Click here to remove the entry from the phrase book.</source>
        <translation>Удалить фразу из глоссария.</translation>
    </message>
    <message>
        <source>&amp;Remove Entry</source>
        <translation>&amp;Удалить</translation>
    </message>
    <message>
        <source>Settin&amp;gs...</source>
        <translation>&amp;Настройки...</translation>
    </message>
    <message>
        <source>Click here to save the changes made.</source>
        <translation>Сохранить изменения.</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Сохранить</translation>
    </message>
    <message>
        <source>Click here to close this window.</source>
        <translation>Закрыть окно.</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
</context>
<context>
    <name>PhraseModel</name>
    <message>
        <source>Source phrase</source>
        <translation>Исходная фраза</translation>
    </message>
    <message>
        <source>Translation</source>
        <translation>Перевод</translation>
    </message>
    <message>
        <source>Definition</source>
        <translation>Определение</translation>
    </message>
</context>
<context>
    <name>PhraseView</name>
    <message>
        <source>Insert</source>
        <translation>Вставить</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Правка</translation>
    </message>
    <message>
        <source>Guess (%1)</source>
        <translation>Похожая (%1)</translation>
    </message>
    <message>
        <source>Guess</source>
        <translation>Похожая</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Translation files (%1);;</source>
        <translation>Файлы перевода (%1);;</translation>
    </message>
    <message>
        <source>All files (*)</source>
        <translation>Все файлы (*)</translation>
    </message>
    <message>
        <source>Qt Linguist</source>
        <translation>Qt Linguist</translation>
    </message>
</context>
<context>
    <name>SourceCodeView</name>
    <message>
        <source>&lt;i&gt;Source code not available&lt;/i&gt;</source>
        <translation>&lt;i&gt;Исходный код недоступен&lt;/i&gt;</translation>
    </message>
    <message>
        <source>&lt;i&gt;File %1 not available&lt;/i&gt;</source>
        <translation>&lt;i&gt;Файл %1 недоступен&lt;/i&gt;</translation>
    </message>
    <message>
        <source>&lt;i&gt;File %1 not readable&lt;/i&gt;</source>
        <translation>&lt;i&gt;Невозможно прочитать файл %1&lt;/i&gt;</translation>
    </message>
</context>
<context>
    <name>Statistics</name>
    <message>
        <source>Statistics</source>
        <translation>Статистика</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <source>Translation</source>
        <translation>Перевод</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Источник</translation>
    </message>
    <message>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <source>Words:</source>
        <translation>Слов:</translation>
    </message>
    <message>
        <source>Characters:</source>
        <translation>Символов:</translation>
    </message>
    <message>
        <source>Characters (with spaces):</source>
        <translation>Символов (с пробелами):</translation>
    </message>
</context>
<context>
    <name>TranslateDialog</name>
    <message>
        <source>This window allows you to search for some text in the translation source file.</source>
        <translation>Данное окно позволяет искать текст в файле перевода.</translation>
    </message>
    <message>
        <source>Type in the text to search for.</source>
        <translation>Введите искомый текст.</translation>
    </message>
    <message>
        <source>Find &amp;source text:</source>
        <translation>&amp;Найти текст:</translation>
    </message>
    <message>
        <source>&amp;Translate to:</source>
        <translation>&amp;Перевести как:</translation>
    </message>
    <message>
        <source>Search options</source>
        <translation>Параметры поиска</translation>
    </message>
    <message>
        <source>Texts such as &apos;TeX&apos; and &apos;tex&apos; are considered as different when checked.</source>
        <translation>Если включено, строки «ПрИмЕр» и «пример» будут считаться разными.</translation>
    </message>
    <message>
        <source>Match &amp;case</source>
        <translation>С учётом &amp;регистра</translation>
    </message>
    <message>
        <source>Mark new translation as &amp;finished</source>
        <translation>Помечать перевод как завер&amp;шённый</translation>
    </message>
    <message>
        <source>Click here to find the next occurrence of the text you typed in.</source>
        <translation>Найти следующее совпадение для введённого текста.</translation>
    </message>
    <message>
        <source>Find Next</source>
        <translation>Найти далее</translation>
    </message>
    <message>
        <source>Translate</source>
        <translation>Перевести</translation>
    </message>
    <message>
        <source>Translate All</source>
        <translation>Перевести все</translation>
    </message>
    <message>
        <source>Click here to close this window.</source>
        <translation>Закрыть окно.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
</context>
<context>
    <name>TranslationSettingsDialog</name>
    <message>
        <source>Source language</source>
        <translation>Исходный язык</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Язык</translation>
    </message>
    <message>
        <source>Country/Region</source>
        <translation>Страна/Регион</translation>
    </message>
    <message>
        <source>Target language</source>
        <translation>Язык перевода</translation>
    </message>
    <message>
        <source>Any Country</source>
        <translation>Любая страна</translation>
    </message>
    <message>
        <source>Settings for &apos;%1&apos; - Qt Linguist</source>
        <translation>Настройки для «%1» - Qt Linguist</translation>
    </message>
</context>
</TS>
